package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.domain.sqmy.SqmyInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.SqmyInfoMapper;
import com.ruoyi.system.service.ISqmyInfoService;

/**
 * 社情民意信息Service业务层处理
 * 
 * @author boman
 * @date 2024-03-14
 */
@Service
public class SqmyInfoServiceImpl implements ISqmyInfoService 
{
    @Autowired
    private SqmyInfoMapper sqmyInfoMapper;

    /**
     * 查询社情民意信息
     * 
     * @param sqmyId 社情民意信息主键
     * @return 社情民意信息
     */
    @Override
    public SqmyInfo selectSqmyInfoBySqmyId(Long sqmyId)
    {
        return sqmyInfoMapper.selectSqmyInfoBySqmyId(sqmyId);
    }

    /**
     * 查询社情民意信息列表
     * 
     * @param sqmyInfo 社情民意信息
     * @return 社情民意信息
     */
    @Override
    public List<SqmyInfo> selectSqmyInfoList(SqmyInfo sqmyInfo)
    {
        return sqmyInfoMapper.selectSqmyInfoList(sqmyInfo);
    }

    /**
     * 新增社情民意信息
     * 
     * @param sqmyInfo 社情民意信息
     * @return 结果
     */
    @Override
    public int insertSqmyInfo(SqmyInfo sqmyInfo)
    {
        sqmyInfo.setCreateTime(DateUtils.getNowDate());
        return sqmyInfoMapper.insertSqmyInfo(sqmyInfo);
    }

    /**
     * 修改社情民意信息
     * 
     * @param sqmyInfo 社情民意信息
     * @return 结果
     */
    @Override
    public int updateSqmyInfo(SqmyInfo sqmyInfo)
    {
        sqmyInfo.setUpdateTime(DateUtils.getNowDate());
        return sqmyInfoMapper.updateSqmyInfo(sqmyInfo);
    }

    /**
     * 批量删除社情民意信息
     * 
     * @param sqmyIds 需要删除的社情民意信息主键
     * @return 结果
     */
    @Override
    public int deleteSqmyInfoBySqmyIds(Long[] sqmyIds)
    {
        return sqmyInfoMapper.deleteSqmyInfoBySqmyIds(sqmyIds);
    }

    /**
     * 删除社情民意信息信息
     * 
     * @param sqmyId 社情民意信息主键
     * @return 结果
     */
    @Override
    public int deleteSqmyInfoBySqmyId(Long sqmyId)
    {
        return sqmyInfoMapper.deleteSqmyInfoBySqmyId(sqmyId);
    }
}
